summaryrefslogtreecommitdiff
path: root/library/rules.gradle
diff options
context:
space:
mode:
Diffstat (limited to 'library/rules.gradle')
-rw-r--r--library/rules.gradle8
1 files changed, 4 insertions, 4 deletions
diff --git a/library/rules.gradle b/library/rules.gradle
index 54ea68b..e261a4c 100644
--- a/library/rules.gradle
+++ b/library/rules.gradle
@@ -16,8 +16,8 @@ android {
flavorDimensions 'compat'
productFlavors {
- // Platform version that will not include the compatibility libraries
- platform {
+ // DEPRECATED: Platform version that will not include the compatibility libraries
+ platformDeprecated {
dimension 'compat'
minSdkVersion 23
}
@@ -37,7 +37,7 @@ android {
res.srcDirs = ['main/res']
}
- platform {
+ platformDeprecated {
java.srcDirs = ['platform/src']
res.srcDirs = ['platform/res']
}
@@ -66,7 +66,7 @@ dependencies {
// deps = ['project-name': 'com.example.group:project-name:1.0.0']
// }
//
- platformCompile deps['support-annotations']
+ platformDeprecatedCompile deps['support-annotations']
gingerbreadCompatCompile deps['support-appcompat-v7']
gingerbreadCompatCompile deps['support-recyclerview-v7']